/************************** namespace for static data **************************/ 
Tine = window.Tine || {};
Tine.__translationData = Tine.__translationData || {};
Tine.__translationData.msgs = Tine.__translationData.msgs || {};
/********************** tine translations of Calendar **********************/ 
Tine.__translationData.msgs['./LC_MESSAGES/Calendar'] = ({
""
: "Project-Id-Version: Tine 2.0\nPOT-Creation-Date: 2008-05-17 22:12+0100\nPO-Revision-Date: 2020-05-11 11:41+0000\nLast-Translator: Christian Feitl <c.feitl@metaways.de>\nLanguage-Team: Chinese (China) (http://www.transifex.com/tine20/tine20/language/zh_CN/)\nLanguage: zh_CN\nMIME-Version: 1.0\nContent-Type: text/plain; charset=UTF-8\nContent-Transfer-Encoding: 8bit\nPlural-Forms: nplurals=1; plural=0;\nX-Poedit-Country: GB\nX-Poedit-Language: en\nX-Poedit-SourceCharset: utf-8\n"

, "{0}, the {1}. of {2}"
: ""

, "Recurrances"
: ""

, "No recurring rule defined"
: ""

, "Details"
: ""

, "None"
: ""

, "Daily"
: "每日"

, "Weekly"
: "每周"

, "Monthly"
: "每月"

, "Yearly"
: "每年"

, "Exceptions of reccuring events can't have recurrences themselves."
: ""

, "at"
: "在"

, "never"
: "从不"

, "after {0} occurrences"
: ""

, "Except"
: ""

, "during events in the calendars"
: ""

, "End"
: "结束"

, "Until has to be after event start"
: ""

, "The event is longer than the recurring interval"
: ""

, "Every {0}. Day"
: ""

, "Every {0}. Week at"
: ""

, "Every {0}. Month"
: ""

, "at the"
: ""

, "first"
: "第一"

, "second"
: "第二"

, "third"
: "第三"

, "fourth"
: "第四"

, "last"
: "最后"

, "Every {0}. Year"
: ""

, "of"
: "的"

, "Summary"
: "摘要"

, "Organizer"
: "组织者"

, "Description"
: "描述"

, "Location"
: "位置"

, "Start Time"
: "开始时间"

, "End Time"
: "结束时间"

, "Attendee"
: "参加者"

, "whole day"
: "整天"

, "Week {0} :"
: ""

, "Poll, Polls"
: [
  ""

]
, "Options"
: ""

, "Alternative Dates"
: ""

, "Set as definite event"
: ""

, "Create Poll for this Event"
: ""

, "Name for poll"
: ""

, "Create scheduling suggestions and pick the best alternative based on user feedback."
: ""

, "Share the link below to poll for attendee status feedback."
: ""

, "Public URL"
: ""

, "Protect poll with a password"
: ""

, "Only invited attendee can reply"
: ""

, "Start Date"
: ""

, "Info"
: ""

, "loading alternative dates"
: ""

, "Select one Event Only"
: ""

, "You need to select exactly one event as the definite event."
: ""

, "Setting definite event"
: ""

, "New Event"
: "新事件"

, "Calendar, Calendars"
: [
  "日历"

]
, "Event not found"
: ""

, "The Event was deleted in the meantime or you don't have access rights to it."
: ""

, "Switch to public poll"
: ""

, "Welcome {name}"
: ""

, "This is a closed poll. No Attendee can be added."
: ""

, "This poll is closed already"
: ""

, "I am not {name}"
: ""

, "Login"
: ""

, "{headerDate, date, full} {headerDate, time, short}"
: ""

, "Cancel"
: ""

, "Save"
: ""

, "By using this service you agree to our terms and conditions"
: ""

, "Use your personal link please."
: ""

, "We have sent it to your E-Mail account again."
: ""

, "If you did not receive the link, please contact the organiser."
: ""

, "Password"
: ""

, "Submit"
: ""

, "Wrong password!"
: ""

, "Please log in"
: ""

, "User name"
: ""

, "Calendar of {name}"
: ""

, "An unexpected error occurred."
: ""

, "Add attendee"
: ""

, "Sort Attendee"
: ""

, "Check to filter for this attendee"
: ""

, "Unavailable"
: ""

, "Loading events, please wait..."
: "加载事件，请等待 ..."

, "Cut event"
: ""

, "Copy Event to clipboard"
: ""

, "Stop cut / copy & paste"
: ""

, "Print Page"
: "打印"

, "Loose-Leaf"
: ""

, "Sheet"
: "工作表"

, "Grid"
: "表格"

, "Timeline"
: ""

, "Day"
: "日期"

, "Week"
: "星期"

, "Month"
: "月"

, "Year"
: ""

, "Custom Selection"
: ""

, "Import Events"
: ""

, "Paste event \"{0}\""
: ""

, "Set my response"
: ""

, "Copy {0}"
: ""

, "Set event status"
: ""

, "Updating event in the past"
: ""

, "Update this event"
: ""

, "Do not update this event"
: ""

, "Creating event in the past"
: ""

, "Create this event"
: ""

, "Do not create this event"
: ""

, "Update this event only"
: ""

, "Update this and all future events"
: ""

, "Update whole series"
: "更新整个系列"

, "Update nothing"
: ""

, "Update Event"
: "更新事件"

, "Please Change Selection"
: "请修改选择"

, "Your selection contains recurring events. Recuring events must be deleted seperatly!"
: ""

, "Delete Event"
: "删除事件"

, "Delete this event only"
: "只删除该事件"

, "Delete this and all future events"
: ""

, "Delete whole series"
: "删除整个系列"

, "Delete nothing"
: ""

, "Do you really want to delete this event?, Do you really want to delete the {0} selected events?"
: [
  ""

]
, "Could not Print"
: "不能打印"

, "Sorry, your current view does not support printing."
: ""

, "Scheduling Conflict"
: ""

, "The following attendee are busy at the requested time:"
: ""

, "Ignore Conflict"
: ""

, "Edit Event"
: "编辑事件"

, "Cancel this action"
: ""

, "Update Status for all Attendee?"
: ""

, "You are about to change the status of the event itself and not just your own status. Do you really want to change the event status for all attendee?"
: ""

, "Manage Resources"
: "管理资源"

, "GENDER_Attendee"
: ""

, "Select Attendee"
: "选择参加者"

, "Attachments"
: ""

, "Private"
: "私人"

, "Tags"
: "标签"

, "Blocking"
: ""

, "Tentative"
: "临时的"

, "Import Definition Success!"
: ""

, "The Ical Import definition has been created successfully! Please wait some minutes to get the events synced by the cronjob."
: ""

, "Choose Import File"
: ""

, "Please choose the file that contains the records you want to add to Tine 2.0"
: ""

, "Select file containing your {0}"
: ""

, "once"
: ""

, "hourly"
: ""

, "daily"
: ""

, "weekly"
: ""

, "Choose Remote Location"
: ""

, "Please choose a remote location you want to add to Tine 2.0"
: ""

, "Username"
: ""

, "Refresh time"
: ""

, "General Settings"
: ""

, "Calendar name (you need permissions to add events)"
: ""

, "What should the file you upload look like?"
: ""

, "Tine 2.0 does not understand all kind of files you might want to upload. You will have to manually adjust your file so Tine 2.0 can handle it."
: ""

, "Following you find a list of all supported import formats and a sample file, how Tine 2.0 expects your file to look like."
: ""

, "Please select the import format of the file you want to upload"
: ""

, "Download example file"
: ""

, "Remote / ICS"
: ""

, "Remote / CalDAV (BETA)"
: ""

, "Upload"
: ""

, "Choose File and Format"
: ""

, "Select type of source"
: ""

, "Please select the type of source you want to add to Tine 2.0"
: ""

, "Importing {0}"
: ""

, "Back"
: ""

, "Next"
: ""

, "Ok"
: ""

, "Free Time Search"
: ""

, "Searching for Free Time..."
: ""

, "No Free Time found"
: ""

, "No free timeslot could be found Until {0}. Do you want to continue?"
: ""

, "Continue"
: ""

, "Give up"
: ""

, "Free Time Search Options"
: ""

, "private classification"
: ""

, "recurring event"
: ""

, "recurring event exception"
: ""

, "has alarm"
: ""

, "has attachments"
: ""

, "is part of an open poll"
: ""

, "Mini Calendar"
: ""

, "WK"
: ""

, "{0} more..."
: ""

, "Resource Grant, Resource Grants"
: [
  ""

]
, "Invite Resource"
: ""

, "The grant to invite the resource to an event"
: ""

, "Read Resource"
: ""

, "The grant to read the resource itself"
: ""

, "Edit Resource"
: ""

, "The grant to edit the resource itself"
: ""

, "Export Resource"
: ""

, "The grant to export the resource itself"
: ""

, "Sync Resource"
: ""

, "The grant to synchronise the resource itself"
: ""

, "Resource Admin"
: ""

, "The grant to administrate the resource itself"
: ""

, "Add Events"
: ""

, "The grant to directly add events into this resource calendar"
: ""

, "Read Events"
: ""

, "The grant to read events from this resource calendar"
: ""

, "Export Events"
: ""

, "The grant to export events from this resource calendar"
: ""

, "Sync Events"
: ""

, "The grant to synchronise events from this resource calendar. Need Read Events Grant"
: ""

, "Events Free Busy"
: ""

, "The grant to get free/busy information of events from this resource calendar"
: ""

, "Edit Events"
: ""

, "The grant to respond to event invitations of this resource and to edit events directly saved in this resource calendar"
: ""

, "Delete Events"
: ""

, "The grant to delete events directly stored in this resource calendar"
: ""

, "Free Busy"
: ""

, "The grant to get free/busy information of events in this calendar"
: ""

, "The grant to access events marked as private in this calendar"
: ""

, "Rrule"
: ""

, "Please choose the Event to add the contacts to"
: ""

, "Role"
: "角色"

, "Select Role"
: "选择角色"

, "Status"
: "状态"

, "Select Status"
: "选择状态"

, "Adding {0} Attendee to event"
: ""

, "no events found"
: ""

, "Searching..."
: ""

, "Search Event"
: ""

, "Event, Events"
: [
  "事件"

]
, "Additional Tags ..."
: ""

, "non-blocking"
: ""

, "Displayed in"
: ""

, "No Information"
: "没有信息"

, "Event Location"
: ""

, "From"
: ""

, "until"
: ""

, "Events"
: "事件"

, "Calendars"
: "日历"

, "Quick Search"
: ""

, "GENDER_Calendar"
: ""

, "Attendee Status"
: ""

, "GENDER_Attendee Status"
: ""

, "Attendee Role"
: ""

, "GENDER_Attendee Role"
: ""

, "GENDER_Status"
: ""

, "GENDER_Blocking"
: ""

, "Classification"
: ""

, "GENDER_Classification"
: ""

, "Last Modified Time"
: ""

, "Last Modified By"
: ""

, "Creation Time"
: ""

, "Created By"
: ""

, "Unknown date"
: ""

, "{0} {1} o'clock"
: ""

, "Event (as attendee)"
: ""

, "Event (as organizer)"
: ""

, "Event attendee"
: "事件参加者"

, "Attender, Attendee"
: [
  "参加者"

]
, "Resource, Resources"
: [
  "资源"

]
, "Resources"
: "资源"

, "Anyone"
: ""

, "Name"
: "名字"

, "Calendar Hierarchy/Name"
: ""

, "Email"
: "电子邮件"

, "Maximum number of attendee"
: ""

, "Type"
: "类型"

, "Default attendee status"
: ""

, "Busy Type"
: ""

, "Event finder options"
: ""

, "Click here to invite another attender..."
: ""

, "User"
: "用户"

, "Group"
: "组"

, "Member of group"
: ""

, "This is the calendar where the attender has saved this event in"
: ""

, "Click icon to change"
: ""

, "Availability of Attendee"
: ""

, "Whole Group or each Member of Group"
: ""

, "Choose \"Group\" to filter for the whole group itself. Choose \"Member of Group\" to filter for each member of the group"
: ""

, "Member of Group"
: ""

, "Loading Groupmembers..."
: ""

, "Remove Attender"
: "移除参加者"

, "Compose email"
: ""

, "Poll URL: {0}"
: ""

, "View Resource"
: ""

, "(as a group member)"
: ""

, "External Attendee"
: ""

, "Originally"
: "原始的"

, "Checking Calendar Data..."
: "检验日历数据中…"

, "Reply to Recurring Event"
: ""

, "You are responding to an recurring event. What would you like to do?"
: ""

, "Respond to whole series"
: ""

, "Do not respond"
: ""

, "The event of this message does not exist"
: ""

, "The sender is not authorised to update the event"
: ""

, "This message is already processed"
: ""

, "You are not an attendee of this event"
: ""

, "This event has been deleted by the organizer"
: ""

, "This event has been canceled."
: ""

, "Unsupported message"
: ""

, "This is an event invitation for someone else."
: ""

, "You have already replied to this event invitation."
: ""

, "The event got rescheduled. Set your response to:"
: ""

, "You received an event invitation. Set your response to:"
: ""

, "An invited attendee responded to the invitation."
: ""

, "Unsupported method"
: ""

, "Suppress notification"
: ""

, "Color"
: ""

, "Enter description..."
: "输入描述 ..."

, "Grants"
: ""

, "This event is originally stored in a calendar you don't have access to."
: ""

, "This event is originally stored in {0}"
: ""

, "This event is additionally displayed in your personal calendar {0}"
: ""

, "Colors"
: ""

, "Side bar color"
: ""

, "Color by Calendar"
: ""

, "Color by Attendee Calendar"
: ""

, "Color by Tags"
: ""

, "Color by Attendee Role"
: ""

, "Colors by response"
: ""

, "Colors by tags"
: ""

, "Colors by attendee"
: ""

, "Colors by resource"
: ""

, "View"
: ""

, "Saved in"
: ""

, "Enter description"
: "输入描述"

, "Notifications are disabled"
: ""

, "Notifications are enabled"
: ""

, "Print Event"
: ""

, "Send Notification?"
: ""

, "Changes to this event might send notifications. Press the button \"Notifcation are enabled\" to switch to \"Notification are disabled\""
: ""

, "End date is not valid"
: "结束日期无效"

, "End date must be after start date"
: "结束日期必须在开始日期之后"

, "End time is not allowed to be after the configured time."
: ""

, "Start date is not valid"
: "开始日期无效"

, "Start date is not allowed to be before the configured time."
: ""

, "The summary must not be longer than 255 characters."
: ""

, "The summary must have at least 1 character."
: ""

, "Summary too Long"
: "总结太长"

, "Summary too Short"
: ""

, "Set This Date as Definite Event?"
: ""

, "Do you want to close the poll and remove all other alternatives?"
: ""

, "Attendee/Resources"
: ""

, "Additional Attendees ..."
: ""

, "Default Status"
: ""

, "No Access"
: ""

, "All my events"
: ""

, "Position on the left time axis, day and week view should start with"
: ""

, "Position on the left time axis, day and week view should end with"
: ""

, "Default Start Time"
: ""

, "Scroll position on the left time axis, day and week view should start with"
: ""

, "Visible Time"
: ""

, "Time to be displayed at once"
: ""

, "Default Calendar"
: "缺省日历"

, "The default calendar for invitations and new events"
: "用于邀请和新事件的缺省日历"

, "Default Favorite"
: ""

, "The default favorite which is loaded on calendar startup"
: ""

, "Get Notification Emails"
: "获得通知电子邮件"

, "The level of actions you want to be notified about. Please note that organizers will get notifications for all updates including attendee answers unless this preference is set to \"Never\""
: "你想要的通知动作级别。请注意组织者将获得所有更新包括参加者的答复，除非这个参数设置为 \"永不\""

, "Send Notifications Emails of own Actions"
: ""

, "Get notifications emails for actions you did yourself"
: ""

, "Send Notifications Emails of tentative events"
: ""

, "Get notifications emails of tentative events"
: ""

, "Send Alarm Notifications Emails"
: ""

, "Get event alarms via email"
: ""

, "Enable Standard Alarm"
: ""

, "New events get a standard alarm as defined below"
: ""

, "Standard Alarm Time"
: ""

, "Minutes before the event starts"
: ""

, "Default Attendee Strategy"
: ""

, "Default Attendee Strategy for new events"
: ""

, "Time Increment"
: ""

, "Increment of event time steps"
: ""

, "Default set Events to privat"
: ""

, "If enabled every created event is always privat"
: ""

, "First Day of Week"
: ""

, "On what day the week should be starting"
: ""

, "Default calendar strategy"
: ""

, "The calendar for new events if no container is selected"
: ""

, "Fixed Calendars"
: "固定日历"

, "Calendars always selected regardless of all filter parameters."
: ""

, "Never"
: ""

, "On invitation and cancellation only"
: ""

, "On time changes"
: ""

, "On all updates but attendee responses"
: ""

, "On attendee responses too"
: ""

, "Calendars always selected regardless of all filter parameters. A valid use case might be to force the display of an certain holiday calendar."
: "无论如何设置筛选参数，这些日历总会被选中。一个合理的用例是：强制显示某个节日日历。"

, "Crop Days"
: ""

, "Crop calendar view configured start and endtime."
: ""

, "Crop Days Limit Override"
: ""

, "Allow events outside start and endtime."
: ""

, "Week View Mouse Wheel Increment"
: ""

, "Default View for Events"
: ""

, "Event Status Available"
: ""

, "Possible event status. Please note that additional event status might impact other calendar systems on export or synchronisation."
: ""

, "Confirmed"
: ""

, "Canceled"
: ""

, "Event Classes Available"
: ""

, "Possible event classes. Please note that additional event classes might impact other calendar systems on export or synchronisation."
: ""

, "Public"
: ""

, "Confidential"
: ""

, "Event Transparencies Available"
: ""

, "Possible event transparencies. Please note that additional event transparencies might impact other calendar systems on export or synchronisation."
: ""

, "Transparent"
: ""

, "Opaque"
: ""

, "Attendee Status Available"
: "参加者的状态"

, "Possible event attendee status. Please note that additional attendee status might impact other calendar systems on export or synchronisation."
: ""

, "No response"
: "没有响应"

, "Accepted"
: "被接受"

, "Declined"
: "被拒绝"

, "Attendee Roles Available"
: ""

, "Possible event attendee roles. Please note that additional attendee roles might impact other calendar systems on export or synchronisation."
: ""

, "Required"
: "要求的"

, "Optional"
: "可选的"

, "Organizer has implicit edit grant"
: ""

, "Resource Types Available"
: ""

, "Possible resource types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Room"
: ""

, "Board"
: ""

, "Cable"
: ""

, "Car"
: ""

, "Coffee"
: ""

, "Homeoffice"
: ""

, "Lamp"
: ""

, "Laptop"
: ""

, "Material"
: ""

, "Projector"
: ""

, "Travel"
: ""

, "Free/Busy Types Available"
: ""

, "Possible free/busy types. Please note that additional free/busy types might impact other calendar systems on export or synchronisation."
: ""

, "Free"
: ""

, "Busy"
: ""

, "Filter timeslot for CalDAV events"
: ""

, "For how long in the past (in months) the events should be synchronized."
: ""

, "Filter timeslot for CalDAV events with SyncToken"
: ""

, "Timeslot for event notifications"
: ""

, "For how long in the past (in weeks) event notifications should be sent."
: ""

, "Default filter period (from) for events fetched via JSON API"
: ""

, "For how long in the past (in months) the events should be fetched."
: ""

, "Default filter period (until) for events fetched via JSON API"
: ""

, "For how long in the future (in months) the events should be fetched."
: ""

, "Disable iMIP for external organizers"
: ""

, "Disable notification for external organizers"
: ""

, "(CalDAV) Skip double events from personal or shared calendar"
: ""

, "(CalDAV) Skip double events from personal or shared calendar (\"personal\" > Skip events from personal calendar or \"shared\" > Skip events from shared calendar)"
: ""

, "Send notifications to every user with edit permissions of the added resources"
: ""

, "Enabled Features"
: ""

, "Enabled Features in Calendar Application."
: ""

, "Calendar Split View"
: ""

, "Split day and week views by attendee"
: ""

, "Calendar Year View"
: ""

, "Adds year view to Calendar"
: ""

, "Calendar Extended Context Menu Actions"
: ""

, "Adds extended actions to event context menus"
: ""

, "Color Events By"
: ""

, "Choose event color by different criteria"
: ""

, "Recur Events Except"
: ""

, "Recur Events except on certain dates"
: ""

, "Activate Poll for Events"
: ""

, "Create alternative Events and let users as well as externals vote for the best option."
: ""

, "Lead Notification Confirmation"
: ""

, "Send Tentative Notifications"
: ""

, "Send notifications to event organiziers of events that are tentative certain days before event is due"
: ""

, "Enabled"
: ""

, "Days Before Due Date"
: ""

, "How many days before the events due date to start send notifications."
: ""

, "Additional Filter"
: ""

, "Additional filter to limit events notifications should be send for."
: ""

, "Mute Event Notifications for Polls"
: ""

, "Do not send invitations notifications for alternative events in an active poll."
: ""

, "GTCs for polls"
: ""

, "Freebusy Info"
: ""

, "What data the freebusy grant reveals"
: ""

, "only date & time"
: ""

, "and organizer"
: ""

, "and resources"
: ""

, "and calendar"
: ""

, "and other attendees"
: ""

, "Search Attenders Additional Filters"
: ""

, "User Additional Filters"
: ""

, "Group Additional Filters"
: ""

, "Resource Additional Filters"
: ""

, "Assign organizer meeting status on editGrant"
: ""

, "%s's personal calendar"
: "%s 的个人日历"

, "Failed"
: ""

, "The right Resource Admin must be set once."
: ""

, "Different Calendar"
: ""

, "Exdate container move are not allowed"
: ""

, "Invalid URL given"
: ""

, "The URL you used is invalid. Please use a valid one!"
: ""

, "Calendars to export"
: ""

, "Export target"
: ""

, "VCalendar/ICS"
: ""

, "Export visible events to ics file"
: ""

, "Excel overview"
: ""

, "Word event sheet"
: ""

, "Export Events as Calendar Sheet"
: ""

, "VCalendar Report"
: ""

, "Export multiple calendars to ics files"
: ""

, "OpenDocument all data"
: ""

, "Export event data into ods spreadsheet"
: ""

, "Word details"
: ""

, "Excel all data"
: ""

, "Shared Calendar CSV"
: ""

, "Resource CSV"
: ""

, "You can not have more than one grants filter"
: ""

, "Import iCal-files"
: ""

, "unknown"
: "不知道"

, "This contact has been automatically added by the system as an event attender"
: ""

, "The email address has been shortened:"
: ""

, "Every %s day"
: ""

, "Every %s week on"
: ""

, "Weekly on"
: ""

, "and"
: ""

, "Every %1$s month on the %2$s %3$s"
: ""

, "Monthly every %1$s %2$s"
: ""

, "Every %1$s month on the %2$s"
: ""

, "Monthly on the %1$s"
: ""

, "Yearly every %1$s %2$s of %3$s"
: ""

, "Yearly on the %1$s of %2$s"
: ""

, "second to last"
: ""

, "fifth"
: ""

, "st"
: ""

, "nd"
: ""

, "rd"
: ""

, "th"
: ""

, "Start"
: "开始"

, "Priority"
: ""

, "Url"
: ""

, "Recurrance rule"
: ""

, "Is all day event"
: "是整日事件"

, "Organizer timezone"
: "组织者时区"

, "Locked"
: ""

, "Closed"
: ""

, "Alarm for event \"%1$s\" at %2$s"
: ""

, "Event invitation \"%1$s\" at %2$s"
: "事件邀请 \"%1$s\" at %2$s"

, "Resource \"%1$s\" was booked for \"%2$s\" at %3$s"
: ""

, "Event \"%1$s\" at %2$s has been canceled"
: "事件 \"%1$s\" at %2$s 被取消"

, "Event \"%1$s\" has been rescheduled from %2$s to %3$s"
: ""

, "Event \"%1$s\" at %2$s has been updated"
: "事件 \"%1$s\" at %2$s 被更新"

, "%1$s accepted event \"%2$s\" at %3$s"
: "%1$s 接受了事件 \"%2$s\" at %3$s"

, "%1$s declined event \"%2$s\" at %3$s"
: "%1$s 拒绝了事件 \"%2$s\" at %3$s"

, "Tentative response from %1$s for event \"%2$s\" at %3$s"
: ""

, "No response from %1$s for event \"%2$s\" at %3$s"
: ""

, "Unknown status update from %1$s for event \"%2$s\" at %3$s"
: ""

, "Attendee changes for event \"%1$s\" at %2$s"
: ""

, "Tentative event notification for event \"%1$s\" at %2$s"
: ""

, "Unknown action"
: ""

, "Resource Management"
: ""

, "The new recurrence rule is unpredictable. Please choose a valid recurrence rule"
: ""

, "Polls for recurring events are not supported"
: ""

, "This contact has been automatically added by the system as a poll attendee"
: ""

, "Attendance Confirmation for Poll \"%1$s\""
: ""

, "%1$s is scheduled for %2$s"
: ""

, "The poll \"%1$s\" has been closed."
: ""

, "The definite event is scheduled for \"%1$s\""
: ""

, "You can review the poll results here:"
: ""

, "Thank you for attendening the poll \"%1$s\""
: ""

, "To review or edit your status please use your personal link:"
: ""

, "Updates"
: "更新"

, "This is an event series exception."
: ""

, "%1$s changed from \"%2$s\" to \"%3$s\""
: ""

, "%1$s has been invited"
: ""

, "%1$s has been removed"
: ""

, "%1$s accepted invitation"
: ""

, "%1$s declined invitation"
: ""

, "Tentative response from %1$s"
: ""

, "No response from %1$s"
: ""

, "\"%2$s\" response from %1$s"
: ""

, "Link"
: ""

, "Event details"
: "事件细节"

, "All events I attend"
: ""

, "Awaiting response"
: ""

, "Events I have not yet responded to"
: ""

, "Declined events"
: ""

, "Events I have declined"
: ""

, "I'm organizer"
: ""

, "Events I'm the organizer of"
: ""

, "manage shared calendars"
: "管理共享日历"

, "Create new shared calendars"
: "创建共享日历"

, "manage shared calendars favorites"
: "管理共享日历的收藏夹"

, "Create or update shared calendars favorites"
: "创建或更新共享日历的收藏夹"

, "manage resources"
: "管理资源"

, "All Rights to administrate resources"
: ""

, "Account"
: ""

, "Exporttime"
: ""

, "First name, ĺast name"
: ""

, "E-Mail address"
: ""

, "Please wait..."
: ""

, "General terms and conditions"
: ""

, "0009326B"
: ""

, "20"
: ""

, "00B359B9"
: ""

, "00997199"
: ""

, "Relation, Relations"
: [
  ""

]
, "Poll"
: ""

, "Calendar"
: "日历"

, "Do you really want to delete this event?"
: ""

, "Resource Grant"
: ""

, "Event"
: "事件"

, "Attender"
: "参加者"

, "Resource"
: "资源"

, "Relation"
: ""

}); 
/********************** translation loaded flag **********************/ 
Tine.__translationData.__isLoaded = true; 
